@@ -1,5 +1,5 @@
 from .io.chem import get_bounds_range
-from .FPSim2lib import SortResults
+from .FPSim2lib.utils import SortResults
 from .base import BaseEngine
 import numpy as np
 import cupy as cp
@@ -46,7 +46,7 @@ class FPSim2CudaEngine(BaseEngine):
                      const unsigned long long int* qcount,
                      const unsigned long long int* db,
                      const unsigned long long int* popcnts,
-                     float* threshold,
+                     const float* threshold,
                      float* out) {{
 
             // Shared block array. Only visible for threads in same block
@@ -148,8 +148,6 @@ class FPSim2CudaEngine(BaseEngine):
         # init sims result array
         sims = cp.zeros(subset_size, dtype="f4")
 
-        # set the threshold variable and run the search
-        threshold = cp.asarray(threshold, dtype="f4")
         self.cupy_kernel(
             self.cuda_db[slice(*fp_range)],
             query,
